# -----------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# -----------------------------------------------------------------------------

"""Help documentation for Service Fabric health commands."""

from knack.help_files import helps

helps['cluster report-health'] = """
    type: command
    short-summary: Sends a health report on the Service Fabric cluster.
    long-summary: Sends a health report on a Service Fabric cluster. The report must
        contain the information about the source of the health report and
        property on which it is reported.
        The report is sent to a Service Fabric gateway node, which forwards to
        the health store.
        The report may be accepted by the gateway, but rejected by the health
        store after extra validation.
        For example, the health store may reject the report because of an
        invalid parameter, like a stale sequence number.
        To see whether the report was applied in the health store, run
        GetClusterHealth and check that the report appears in the HealthEvents
        section.
    parameters:
        - name: --source-id
          type: string
          short-summary: The source name that identifies the
            client/watchdog/system component that generated the health
            information.
        - name: --health-property
          type: string
          short-summary: The property of the health information.
          long-summary: An entity can have health reports for different
            properties. The property is a string and not a fixed enumeration to
            allow the reporter flexibility to categorize the state condition that
            triggers the report. For example, a reporter with SourceId
            "LocalWatchdog" can monitor the state of the available disk on a
            node, so it can report "AvailableDisk" property on that node. The
            same reporter can monitor the node connectivity, so it can report a
            property "Connectivity" on the same node. In the health store,
            these reports are treated as separate health events for the
            specified node. Together with the SourceId, the property uniquely
            identifies the health information.
        - name: --health-state
          type: string
          short-summary: "Possible values include: 'Invalid', 'Ok', 'Warning',
            'Error', 'Unknown'"
        - name: --ttl
          type: string
          short-summary: The duration for which this health report is valid. 
            This field uses ISO8601 format for specifying the duration.
          long-summary: When clients report periodically, they should send
            reports with higher frequency than time to live. If clients report
            on transition, they can set the time to live to infinite. When
            time to live expires, the health event that contains the health
            information is either removed from health store, if
            RemoveWhenExpired is true, or evaluated at error, if
            RemoveWhenExpired false. If not specified, time to live defaults
            to infinite value.
        - name: --description
          type: string
          short-summary: The description of the health information.
          long-summary: It represents free text used to add human readable
            information about the report. The maximum string length for the
            description is 4096 characters. If the provided string is longer,
            it will be automatically truncated. When truncated, the last
            characters of the description contain a marker "[Truncated]", and
            total string size is 4096 characters. The presence of the marker
            indicates to users that truncation occurred. Note that when
            truncated, the description has less than 4096 characters from the
            original string.
        - name: --sequence-number
          type: string
          short-summary: The sequence number for this health report as a
            numeric string.
          long-summary: The report sequence number is used by the health store
            to detect stale reports. If not specified, a sequence number is
            auto-generated by the health client when a report is added.
        - name: --remove-when-expired
          type: bool
          short-summary: Value that indicates whether the report is removed
            from health store when it expires.
          long-summary: If set to true, the report is removed from the health
            store after it expires. If set to false, the report is treated as
            an error when expired. The value of this property is false by
            default. When clients report periodically, they should set
            RemoveWhenExpired false (default). This way, is the reporter has
            issues (e.g. deadlock) and can't report, the entity is evaluated at
            error when the health report expires. This flags the entity as
            being in Error health state.
        - name: --immediate
          type: bool
          short-summary: A flag that indicates whether the report should be
            sent immediately.
          long-summary: A health report is sent to a Service Fabric gateway
            Application, which forwards to the health store. If Immediate is
            set to true, the report is sent immediately from HTTP Gateway to
            the health store, regardless of the fabric client settings that
            the HTTP Gateway Application is using. This is useful for critical
            reports that should be sent as soon as possible. Depending on
            timing and other conditions, sending the report may still fail,
            for example if the HTTP Gateway is closed or the message doesn't
            reach the Gateway. If Immediate is set to false, the report is sent
            based on the health client settings from the HTTP Gateway.
            Therefore, it will be batched according to the
            HealthReportSendInterval configuration. This is the recommended
            setting because it allows the health client to optimize health
            reporting messages to health store as well as health report
            processing. By default, reports are not sent immediately.
"""

helps['node report-health'] = """
    type: command
    short-summary: Sends a health report on the Service Fabric node.
    long-summary: Reports health state of the specified Service Fabric node.
        The report must contain the information about the source of the health
        report and property on which it is reported. The report is sent to a
        Service Fabric gateway node, which forwards to the health store. The
        report may be accepted by the gateway, but rejected by the health store
        after extra validation. For example, the health store may reject the
        report because of an invalid parameter, like a stale sequence number.
        To see whether the report was applied in the health store, check that
        the report appears in the HealthEvents section.
    parameters:
        - name: --node-name
          type: string
          short-summary: The name of the node.
        - name: --source-id
          type: string
          short-summary: The source name that identifies the
            client/watchdog/system component that generated the health
            information.
        - name: --health-property
          type: string
          short-summary: The property of the health information.
          long-summary: An entity can have health reports for different
            properties. The property is a string and not a fixed enumeration to
            allow the reporter flexibility to categorize the state condition that
            triggers the report. For example, a reporter with SourceId
            "LocalWatchdog" can monitor the state of the available disk on a
            node, so it can report "AvailableDisk" property on that node. The
            same reporter can monitor the node connectivity, so it can report a
            property "Connectivity" on the same node. In the health store,
            these reports are treated as separate health events for the
            specified node. Together with the SourceId, the property uniquely
            identifies the health information.
        - name: --health-state
          type: string
          short-summary: "Possible values include: 'Invalid', 'Ok', 'Warning',
            'Error', 'Unknown'"
        - name: --ttl
          type: string
          short-summary: The duration for which this health report is valid. 
            This field uses ISO8601 format for specifying the duration.
          long-summary: When clients report periodically, they should send
            reports with higher frequency than time to live. If clients report
            on transition, they can set the time to live to infinite. When
            time to live expires, the health event that contains the health
            information is either removed from health store, if
            RemoveWhenExpired is true, or evaluated at error, if
            RemoveWhenExpired false. If not specified, time to live defaults
            to infinite value.
        - name: --description
          type: string
          short-summary: The description of the health information.
          long-summary: It represents free text used to add human readable
            information about the report. The maximum string length for the
            description is 4096 characters. If the provided string is longer,
            it will be automatically truncated. When truncated, the last
            characters of the description contain a marker "[Truncated]", and
            total string size is 4096 characters. The presence of the marker
            indicates to users that truncation occurred. Note that when
            truncated, the description has less than 4096 characters from the
            original string.
        - name: --sequence-number
          type: string
          short-summary: The sequence number for this health report as a
            numeric string.
          long-summary: The report sequence number is used by the health store
            to detect stale reports. If not specified, a sequence number is
            auto-generated by the health client when a report is added.
        - name: --remove-when-expired
          type: bool
          short-summary: Value that indicates whether the report is removed
            from health store when it expires.
          long-summary: If set to true, the report is removed from the health
            store after it expires. If set to false, the report is treated as
            an error when expired. The value of this property is false by
            default. When clients report periodically, they should set
            RemoveWhenExpired false (default). This way, is the reporter has
            issues (e.g. deadlock) and can't report, the entity is evaluated at
            error when the health report expires. This flags the entity as
            being in Error health state.
        - name: --immediate
          type: bool
          short-summary: A flag that indicates whether the report should be
            sent immediately.
          long-summary: A health report is sent to a Service Fabric gateway
            Application, which forwards to the health store. If Immediate is
            set to true, the report is sent immediately from HTTP Gateway to
            the health store, regardless of the fabric client settings that
            the HTTP Gateway Application is using. This is useful for critical
            reports that should be sent as soon as possible. Depending on
            timing and other conditions, sending the report may still fail,
            for example if the HTTP Gateway is closed or the message doesn't
            reach the Gateway. If Immediate is set to false, the report is sent
            based on the health client settings from the HTTP Gateway.
            Therefore, it will be batched according to the
            HealthReportSendInterval configuration. This is the recommended
            setting because it allows the health client to optimize health
            reporting messages to health store as well as health report
            processing. By default, reports are not sent immediately.
"""

helps['application report-health'] = """
    type: command
    short-summary: Sends a health report on the Service Fabric application
    long-summary: Reports health state of the specified Service Fabric
        application. The report must contain the information about the source
        of the health report and property on which it is reported.
        The report is sent to a Service Fabric gateway Application, which
        forwards to the health store. The report may be accepted by the
        gateway, but rejected by the health store after extra validation.
        For example, the health store may reject the report because of an
        invalid parameter, like a stale sequence number. To see whether the
        report was applied in the health store, get application health and
        check that the report appears.
    parameters:
        - name: --application-id
          type: string
          short-summary: The identity of the application
          long-summary: "This is typically the full name of the application
            without the 'fabric:' URI scheme. Starting from version 6.0,
            hierarchical names are delimited with the '~' character. For
            example, if the application name is 'fabric:/myapp/app1', the
            application identity would be 'myapp~app1' in 6.0+ and 'myapp/app1'
            in previous versions."
        - name: --source-id
          type: string
          short-summary: The source name that identifies the
            client/watchdog/system component that generated the health
            information.
        - name: --health-property
          type: string
          short-summary: The property of the health information.
          long-summary: An entity can have health reports for different
            properties. The property is a string and not a fixed enumeration to
            allow the reporter flexibility to categorize the state condition that
            triggers the report. For example, a reporter with SourceId
            "LocalWatchdog" can monitor the state of the available disk on a
            node, so it can report "AvailableDisk" property on that node. The
            same reporter can monitor the node connectivity, so it can report a
            property "Connectivity" on the same node. In the health store,
            these reports are treated as separate health events for the
            specified node. Together with the SourceId, the property uniquely
            identifies the health information.
        - name: --health-state
          type: string
          short-summary: "Possible values include: 'Invalid', 'Ok', 'Warning',
            'Error', 'Unknown'"
        - name: --ttl
          type: string
          short-summary: The duration for which this health report is valid. 
            This field uses ISO8601 format for specifying the duration.
          long-summary: When clients report periodically, they should send
            reports with higher frequency than time to live. If clients report
            on transition, they can set the time to live to infinite. When
            time to live expires, the health event that contains the health
            information is either removed from health store, if
            RemoveWhenExpired is true, or evaluated at error, if
            RemoveWhenExpired false. If not specified, time to live defaults
            to infinite value.
        - name: --description
          type: string
          short-summary: The description of the health information.
          long-summary: It represents free text used to add human readable
            information about the report. The maximum string length for the
            description is 4096 characters. If the provided string is longer,
            it will be automatically truncated. When truncated, the last
            characters of the description contain a marker "[Truncated]", and
            total string size is 4096 characters. The presence of the marker
            indicates to users that truncation occurred. Note that when
            truncated, the description has less than 4096 characters from the
            original string.
        - name: --sequence-number
          type: string
          short-summary: The sequence number for this health report as a
            numeric string.
          long-summary: The report sequence number is used by the health store
            to detect stale reports. If not specified, a sequence number is
            auto-generated by the health client when a report is added.
        - name: --remove-when-expired
          type: bool
          short-summary: Value that indicates whether the report is removed
            from health store when it expires.
          long-summary: If set to true, the report is removed from the health
            store after it expires. If set to false, the report is treated as
            an error when expired. The value of this property is false by
            default. When clients report periodically, they should set
            RemoveWhenExpired false (default). This way, is the reporter has
            issues (e.g. deadlock) and can't report, the entity is evaluated at
            error when the health report expires. This flags the entity as
            being in Error health state.
        - name: --immediate
          type: bool
          short-summary: A flag that indicates whether the report should be
            sent immediately.
          long-summary: A health report is sent to a Service Fabric gateway
            Application, which forwards to the health store. If Immediate is
            set to true, the report is sent immediately from HTTP Gateway to
            the health store, regardless of the fabric client settings that
            the HTTP Gateway Application is using. This is useful for critical
            reports that should be sent as soon as possible. Depending on
            timing and other conditions, sending the report may still fail,
            for example if the HTTP Gateway is closed or the message doesn't
            reach the Gateway. If Immediate is set to false, the report is sent
            based on the health client settings from the HTTP Gateway.
            Therefore, it will be batched according to the
            HealthReportSendInterval configuration. This is the recommended
            setting because it allows the health client to optimize health
            reporting messages to health store as well as health report
            processing. By default, reports are not sent immediately.
"""

helps['service report-health'] = """
    type: command
    short-summary: Sends a health report on the Service Fabric service
    long-summary: Reports health state of the specified Service Fabric service.
      The report must contain the information about the source of the health
      report and property on which it is reported. The report is sent to a
      Service Fabric gateway Service, which forwards to the health store.
      The report may be accepted by the gateway, but rejected by the health
      store after extra validation. For example, the health store may reject
      the report because of an invalid parameter, like a stale sequence number.
      To see whether the report was applied in the health store, check that the
      report appears in the health events of the service.
    parameters:
        - name: --service-id
          type: string
          short-summary: The identity of the service.
          long-summary: "This is typically the full name of the service without
            the 'fabric:' URI scheme. Starting from version 6.0, hierarchical
            names are delimited with the '~' character. For example, if the
            service name is 'fabric:/myapp/app1/svc1', the service identity
            would be 'myapp~app1~svc1' in 6.0+ and 'myapp/app1/svc1' in
            previous versions."
        - name: --source-id
          type: string
          short-summary: The source name that identifies the
            client/watchdog/system component that generated the health
            information.
        - name: --health-property
          type: string
          short-summary: The property of the health information.
          long-summary: An entity can have health reports for different
            properties. The property is a string and not a fixed enumeration to
            allow the reporter flexibility to categorize the state condition that
            triggers the report. For example, a reporter with SourceId
            "LocalWatchdog" can monitor the state of the available disk on a
            node, so it can report "AvailableDisk" property on that node. The
            same reporter can monitor the node connectivity, so it can report a
            property "Connectivity" on the same node. In the health store,
            these reports are treated as separate health events for the
            specified node. Together with the SourceId, the property uniquely
            identifies the health information.
        - name: --health-state
          type: string
          short-summary: "Possible values include: 'Invalid', 'Ok', 'Warning',
            'Error', 'Unknown'"
        - name: --ttl
          type: string
          short-summary: The duration for which this health report is valid. 
            This field uses ISO8601 format for specifying the duration.
          long-summary: When clients report periodically, they should send
            reports with higher frequency than time to live. If clients report
            on transition, they can set the time to live to infinite. When
            time to live expires, the health event that contains the health
            information is either removed from health store, if
            RemoveWhenExpired is true, or evaluated at error, if
            RemoveWhenExpired false. If not specified, time to live defaults
            to infinite value.
        - name: --description
          type: string
          short-summary: The description of the health information.
          long-summary: It represents free text used to add human readable
            information about the report. The maximum string length for the
            description is 4096 characters. If the provided string is longer,
            it will be automatically truncated. When truncated, the last
            characters of the description contain a marker "[Truncated]", and
            total string size is 4096 characters. The presence of the marker
            indicates to users that truncation occurred. Note that when
            truncated, the description has less than 4096 characters from the
            original string.
        - name: --sequence-number
          type: string
          short-summary: The sequence number for this health report as a
            numeric string.
          long-summary: The report sequence number is used by the health store
            to detect stale reports. If not specified, a sequence number is
            auto-generated by the health client when a report is added.
        - name: --remove-when-expired
          type: bool
          short-summary: Value that indicates whether the report is removed
            from health store when it expires.
          long-summary: If set to true, the report is removed from the health
            store after it expires. If set to false, the report is treated as
            an error when expired. The value of this property is false by
            default. When clients report periodically, they should set
            RemoveWhenExpired false (default). This way, is the reporter has
            issues (e.g. deadlock) and can't report, the entity is evaluated at
            error when the health report expires. This flags the entity as
            being in Error health state.
        - name: --immediate
          type: bool
          short-summary: A flag that indicates whether the report should be
            sent immediately.
          long-summary: A health report is sent to a Service Fabric gateway
            Application, which forwards to the health store. If Immediate is
            set to true, the report is sent immediately from HTTP Gateway to
            the health store, regardless of the fabric client settings that
            the HTTP Gateway Application is using. This is useful for critical
            reports that should be sent as soon as possible. Depending on
            timing and other conditions, sending the report may still fail,
            for example if the HTTP Gateway is closed or the message doesn't
            reach the Gateway. If Immediate is set to false, the report is sent
            based on the health client settings from the HTTP Gateway.
            Therefore, it will be batched according to the
            HealthReportSendInterval configuration. This is the recommended
            setting because it allows the health client to optimize health
            reporting messages to health store as well as health report
            processing. By default, reports are not sent immediately.
"""

helps['partition report-health'] = """
    type: command
    short-summary: Sends a health report on the Service Fabric partition.
    long-summary: Reports health state of the specified Service Fabric
        partition. The report must contain the information about the source of
        the health report and property on which it is reported. The report is
        sent to a Service Fabric gateway Partition, which forwards to the
        health store. The report may be accepted by the gateway, but rejected
        by the health store after extra validation. For example, the health
        store may reject the report because of an invalid parameter, like a
        stale sequence number. To see whether the report was applied in the
        health store, check that the report appears in the events section.
    parameters:
        - name: --partition-id
          type: string
          short-summary: The identity of the partition
        - name: --source-id
          type: string
          short-summary: The source name that identifies the
            client/watchdog/system component that generated the health
            information.
        - name: --health-property
          type: string
          short-summary: The property of the health information.
          long-summary: An entity can have health reports for different
            properties. The property is a string and not a fixed enumeration to
            allow the reporter flexibility to categorize the state condition that
            triggers the report. For example, a reporter with SourceId
            "LocalWatchdog" can monitor the state of the available disk on a
            node, so it can report "AvailableDisk" property on that node. The
            same reporter can monitor the node connectivity, so it can report a
            property "Connectivity" on the same node. In the health store,
            these reports are treated as separate health events for the
            specified node. Together with the SourceId, the property uniquely
            identifies the health information.
        - name: --health-state
          type: string
          short-summary: "Possible values include: 'Invalid', 'Ok', 'Warning',
            'Error', 'Unknown'"
        - name: --ttl
          type: string
          short-summary: The duration for which this health report is valid. 
            This field uses ISO8601 format for specifying the duration.
          long-summary: When clients report periodically, they should send
            reports with higher frequency than time to live. If clients report
            on transition, they can set the time to live to infinite. When
            time to live expires, the health event that contains the health
            information is either removed from health store, if
            RemoveWhenExpired is true, or evaluated at error, if
            RemoveWhenExpired false. If not specified, time to live defaults
            to infinite value.
        - name: --description
          type: string
          short-summary: The description of the health information.
          long-summary: It represents free text used to add human readable
            information about the report. The maximum string length for the
            description is 4096 characters. If the provided string is longer,
            it will be automatically truncated. When truncated, the last
            characters of the description contain a marker "[Truncated]", and
            total string size is 4096 characters. The presence of the marker
            indicates to users that truncation occurred. Note that when
            truncated, the description has less than 4096 characters from the
            original string.
        - name: --sequence-number
          type: string
          short-summary: The sequence number for this health report as a
            numeric string.
          long-summary: The report sequence number is used by the health store
            to detect stale reports. If not specified, a sequence number is
            auto-generated by the health client when a report is added.
        - name: --remove-when-expired
          type: bool
          short-summary: Value that indicates whether the report is removed
            from health store when it expires.
          long-summary: If set to true, the report is removed from the health
            store after it expires. If set to false, the report is treated as
            an error when expired. The value of this property is false by
            default. When clients report periodically, they should set
            RemoveWhenExpired false (default). This way, is the reporter has
            issues (e.g. deadlock) and can't report, the entity is evaluated at
            error when the health report expires. This flags the entity as
            being in Error health state.
        - name: --immediate
          type: bool
          short-summary: A flag that indicates whether the report should be
            sent immediately.
          long-summary: A health report is sent to a Service Fabric gateway
            Application, which forwards to the health store. If Immediate is
            set to true, the report is sent immediately from HTTP Gateway to
            the health store, regardless of the fabric client settings that
            the HTTP Gateway Application is using. This is useful for critical
            reports that should be sent as soon as possible. Depending on
            timing and other conditions, sending the report may still fail,
            for example if the HTTP Gateway is closed or the message doesn't
            reach the Gateway. If Immediate is set to false, the report is sent
            based on the health client settings from the HTTP Gateway.
            Therefore, it will be batched according to the
            HealthReportSendInterval configuration. This is the recommended
            setting because it allows the health client to optimize health
            reporting messages to health store as well as health report
            processing. By default, reports are not sent immediately.
"""

helps['replica report-health'] = """
    type: command
    short-summary: Sends a health report on the Service Fabric replica
    long-summary: Reports health state of the specified Service Fabric replica.
        The report must contain the information about the source of the health
        report and property on which it is reported. The report is sent to a
        Service Fabric gateway Replica, which forwards to the health store. The
        report may be accepted by the gateway, but rejected by the health store
        after extra validation. For example, the health store may reject the
        report because of an invalid parameter, like a stale sequence number.
        To see whether the report was applied in the health store, 
        run get replica health and check that the report appears in the HealthEvents section.
    parameters:
        - name: --partition-id
          type: string
          short-summary: The identity of the partition
        - name: --replica-id
          type: string
          short-summary: The identity of the partition
        - name: --service-kind
          type: string
          short-summary: "The kind of service replica (stateless or stateful)
            for which the health is being reported. Following are the possible
            values: 'Stateless', 'Stateful'."
        - name: --source-id
          type: string
          short-summary: The source name that identifies the
            client/watchdog/system component that generated the health
            information.
        - name: --health-property
          type: string
          short-summary: The property of the health information.
          long-summary: An entity can have health reports for different
            properties. The property is a string and not a fixed enumeration to
            allow the reporter flexibility to categorize the state condition that
            triggers the report. For example, a reporter with SourceId
            "LocalWatchdog" can monitor the state of the available disk on a
            node, so it can report "AvailableDisk" property on that node. The
            same reporter can monitor the node connectivity, so it can report a
            property "Connectivity" on the same node. In the health store,
            these reports are treated as separate health events for the
            specified node. Together with the SourceId, the property uniquely
            identifies the health information.
        - name: --health-state
          type: string
          short-summary: "Possible values include: 'Invalid', 'Ok', 'Warning',
            'Error', 'Unknown'"
        - name: --ttl
          type: string
          short-summary: The duration for which this health report is valid. 
            This field uses ISO8601 format for specifying the duration.
          long-summary: When clients report periodically, they should send
            reports with higher frequency than time to live. If clients report
            on transition, they can set the time to live to infinite. When
            time to live expires, the health event that contains the health
            information is either removed from health store, if
            RemoveWhenExpired is true, or evaluated at error, if
            RemoveWhenExpired false. If not specified, time to live defaults
            to infinite value.
        - name: --description
          type: string
          short-summary: The description of the health information.
          long-summary: It represents free text used to add human readable
            information about the report. The maximum string length for the
            description is 4096 characters. If the provided string is longer,
            it will be automatically truncated. When truncated, the last
            characters of the description contain a marker "[Truncated]", and
            total string size is 4096 characters. The presence of the marker
            indicates to users that truncation occurred. Note that when
            truncated, the description has less than 4096 characters from the
            original string.
        - name: --sequence-number
          type: string
          short-summary: The sequence number for this health report as a
            numeric string.
          long-summary: The report sequence number is used by the health store
            to detect stale reports. If not specified, a sequence number is
            auto-generated by the health client when a report is added.
        - name: --remove-when-expired
          type: bool
          short-summary: Value that indicates whether the report is removed
            from health store when it expires.
          long-summary: If set to true, the report is removed from the health
            store after it expires. If set to false, the report is treated as
            an error when expired. The value of this property is false by
            default. When clients report periodically, they should set
            RemoveWhenExpired false (default). This way, is the reporter has
            issues (e.g. deadlock) and can't report, the entity is evaluated at
            error when the health report expires. This flags the entity as
            being in Error health state.
        - name: --immediate
          type: bool
          short-summary: A flag that indicates whether the report should be
            sent immediately.
          long-summary: A health report is sent to a Service Fabric gateway
            Application, which forwards to the health store. If Immediate is
            set to true, the report is sent immediately from HTTP Gateway to
            the health store, regardless of the fabric client settings that
            the HTTP Gateway Application is using. This is useful for critical
            reports that should be sent as soon as possible. Depending on
            timing and other conditions, sending the report may still fail,
            for example if the HTTP Gateway is closed or the message doesn't
            reach the Gateway. If Immediate is set to false, the report is sent
            based on the health client settings from the HTTP Gateway.
            Therefore, it will be batched according to the
            HealthReportSendInterval configuration. This is the recommended
            setting because it allows the health client to optimize health
            reporting messages to health store as well as health report
            processing. By default, reports are not sent immediately.
"""

# SIG # Begin Windows Authenticode signature block
# MIIoLQYJKoZIhvcNAQcCoIIoHjCCKBoCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQse8BENmB6EqSR2hd
# JGAGggIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCDafCh01fj+GW5f
# FJQaSZQEfsojO06FioOuFROggDam+aCCDXYwggX0MIID3KADAgECAhMzAAADrzBA
# DkyjTQVBAAAAAAOvMA0GCSqGSIb3DQEBCwUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjMxMTE2MTkwOTAwWhcNMjQxMTE0MTkwOTAwWjB0MQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMR4wHAYDVQQDExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB
# AQDOS8s1ra6f0YGtg0OhEaQa/t3Q+q1MEHhWJhqQVuO5amYXQpy8MDPNoJYk+FWA
# hePP5LxwcSge5aen+f5Q6WNPd6EDxGzotvVpNi5ve0H97S3F7C/axDfKxyNh21MG
# 0W8Sb0vxi/vorcLHOL9i+t2D6yvvDzLlEefUCbQV/zGCBjXGlYJcUj6RAzXyeNAN
# xSpKXAGd7Fh+ocGHPPphcD9LQTOJgG7Y7aYztHqBLJiQQ4eAgZNU4ac6+8LnEGAL
# go1ydC5BJEuJQjYKbNTy959HrKSu7LO3Ws0w8jw6pYdC1IMpdTkk2puTgY2PDNzB
# tLM4evG7FYer3WX+8t1UMYNTAgMBAAGjggFzMIIBbzAfBgNVHSUEGDAWBgorBgEE
# AYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQURxxxNPIEPGSO8kqz+bgCAQWGXsEw
# RQYDVR0RBD4wPKQ6MDgxHjAcBgNVBAsTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEW
# MBQGA1UEBRMNMjMwMDEyKzUwMTgyNjAfBgNVHSMEGDAWgBRIbmTlUAXTgqoXNzci
# tW2oynUClTBUBgNVHR8ETTBLMEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20vcGtpb3BzL2NybC9NaWNDb2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3JsMGEG
# CCsGAQUFBwEBBFUwUzBRBggrBgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3NvZnQu
# Y29tL3BraW9wcy9jZXJ0cy9NaWNDb2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3J0
# MAwGA1UdEwEB/wQCMAAwDQYJKoZIhvcNAQELBQADggIBAISxFt/zR2frTFPB45Yd
# mhZpB2nNJoOoi+qlgcTlnO4QwlYN1w/vYwbDy/oFJolD5r6FMJd0RGcgEM8q9TgQ
# 2OC7gQEmhweVJ7yuKJlQBH7P7Pg5RiqgV3cSonJ+OM4kFHbP3gPLiyzssSQdRuPY
# 1mIWoGg9i7Y4ZC8ST7WhpSyc0pns2XsUe1XsIjaUcGu7zd7gg97eCUiLRdVklPmp
# XobH9CEAWakRUGNICYN2AgjhRTC4j3KJfqMkU04R6Toyh4/Toswm1uoDcGr5laYn
# TfcX3u5WnJqJLhuPe8Uj9kGAOcyo0O1mNwDa+LhFEzB6CB32+wfJMumfr6degvLT
# e8x55urQLeTjimBQgS49BSUkhFN7ois3cZyNpnrMca5AZaC7pLI72vuqSsSlLalG
# OcZmPHZGYJqZ0BacN274OZ80Q8B11iNokns9Od348bMb5Z4fihxaBWebl8kWEi2O
# PvQImOAeq3nt7UWJBzJYLAGEpfasaA3ZQgIcEXdD+uwo6ymMzDY6UamFOfYqYWXk
# ntxDGu7ngD2ugKUuccYKJJRiiz+LAUcj90BVcSHRLQop9N8zoALr/1sJuwPrVAtx
# HNEgSW+AKBqIxYWM4Ev32l6agSUAezLMbq5f3d8x9qzT031jMDT+sUAoCw0M5wVt
# CUQcqINPuYjbS1WgJyZIiEkBMIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkq
# hkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
# EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
# bjEyMDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5
# IDIwMTEwHhcNMTEwNzA4MjA1OTA5WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQG
# EwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
# A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQg
# Q29kZSBTaWduaW5nIFBDQSAyMDExMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIIC
# CgKCAgEAq/D6chAcLq3YbqqCEE00uvK2WCGfQhsqa+laUKq4BjgaBEm6f8MMHt03
# a8YS2AvwOMKZBrDIOdUBFDFC04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv2akr
# rnoJr9eWWcpgGgXpZnboMlImEi/nqwhQz7NEt13YxC4Ddato88tt8zpcoRb0Rrrg
# OGSsbmQ1eKagYw8t00CT+OPeBw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy
# 4BI6t0le2O3tQ5GD2Xuye4Yb2T6xjF3oiU+EGvKhL1nkkDstrjNYxbc+/jLTswM9
# sbKvkjh+0p2ALPVOVpEhNSXDOW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAh
# dCVfGCi2zCcoOCWYOUo2z3yxkq4cI6epZuxhH2rhKEmdX4jiJV3TIUs+UsS1Vz8k
# A/DRelsv1SPjcF0PUUZ3s/gA4bysAoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTB
# w3J64HLnJN+/RpnF78IcV9uDjexNSTCnq47f7Fufr/zdsGbiwZeBe+3W7UvnSSmn
# Eyimp31ngOaKYnhfsi+E11ecXL93KCjx7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90
# lfdu+HggWCwTXWCVmj5PM4TasIgX3p5O9JawvEagbJjS4NaIjAsCAwEAAaOCAe0w
# ggHpMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1UdDgQWBBRIbmTlUAXTgqoXNzcitW2o
# ynUClTAZBgkrBgEEAYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYD
# VR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBRyLToCMZBDuRQFTuHqp8cx0SOJNDBa
# BgNVHR8EUzBRME+gTaBLhklodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2Ny
# bC9wcm9kdWN0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFfMDNfMjIuY3JsMF4GCCsG
# AQUFBwEBBFIwUDBOBggrBgEFBQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29t
# L3BraS9jZXJ0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFfMDNfMjIuY3J0MIGfBgNV
# HSAEgZcwgZQwgZEGCSsGAQQBgjcuAzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3
# dy5taWNyb3NvZnQuY29tL3BraW9wcy9kb2NzL3ByaW1hcnljcHMuaHRtMEAGCCsG
# AQUFBwICMDQeMiAdAEwAZQBnAGEAbABfAHAAbwBsAGkAYwB5AF8AcwB0AGEAdABl
# AG0AZQBuAHQALiAdMA0GCSqGSIb3DQEBCwUAA4ICAQBn8oalmOBUeRou09h0ZyKb
# C5YR4WOSmUKWfdJ5DJDBZV8uLD74w3LRbYP+vj/oCso7v0epo/Np22O/IjWll11l
# hJB9i0ZQVdgMknzSGksc8zxCi1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlEPXh6
# I/MTfaaQdION9MsmAkYqwooQu6SpBQyb7Wj6aC6VoCo/KmtYSWMfCWluWpiW5IP0
# wI/zRive/DvQvTXvbiWu5a8n7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560
# STkKxgrCxq2u5bLZ2xWIUUVYODJxJxp/sfQn+N4sOiBpmLJZiWhub6e3dMNABQam
# ASooPoI/E01mC8CzTfXhj38cbxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGa
# J+HNpZfQ7l1jQeNbB5yHPgZ3BtEGsXUfFL5hYbXw3MYbBL7fQccOKO7eZS/sl/ah
# XJbYANahRr1Z85elCUtIEJmAH9AAKcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA
# 9Z74v2u3S5fi63V4GuzqN5l5GEv/1rMjaHXmr/r8i+sLgOppO6/8MO0ETI7f33Vt
# Y5E90Z1WTk+/gFcioXgRMiF670EKsT/7qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr
# /Xmfwb1tbWrJUnMTDXpQzTGCGg0wghoJAgEBMIGVMH4xCzAJBgNVBAYTAlVTMRMw
# EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
# aWNyb3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNp
# Z25pbmcgUENBIDIwMTECEzMAAAOvMEAOTKNNBUEAAAAAA68wDQYJYIZIAWUDBAIB
# BQCgga4wGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEO
# MAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEIKZm1AI2y8AfndS1/fRmHkKi
# yobbcNfqhHUJ23ZIg+6DMEIGCisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8A
# cwBvAGYAdKEagBhodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20wDQYJKoZIhvcNAQEB
# BQAEggEAObyNc9Lo/dY2EMN65nxZkUkHVe+iUqSPYQHCbRAy8hUry8yXVEEfKkjb
# ozTiTJcRxa0wOY1Qnk3Qk39Ni3V/ivqPyy6J689ouzkjOY4WpANseXODZh4qLm8M
# wlicUgphrZ2ZqPalB0TypqVo1bzz3jcDbZNPGH+p5cp/36gCLMF+BDSH/AMrqWlo
# Zai7EpZzH+0sh/dy36eV+yAdx3bQuDHH/jv1KtfENamMwPUON2RHH5jCX44Mh0RO
# Ey4pc62eb6cD4fbCP8iha42jlHEFmBmmevG+/Q8lBfnvsBmf24lu4sXlEHdLuYiE
# HqoQtSlt7cqRPmob7ZQGFenRUBK926GCF5cwgheTBgorBgEEAYI3AwMBMYIXgzCC
# F38GCSqGSIb3DQEHAqCCF3AwghdsAgEDMQ8wDQYJYIZIAWUDBAIBBQAwggFSBgsq
# hkiG9w0BCRABBKCCAUEEggE9MIIBOQIBAQYKKwYBBAGEWQoDATAxMA0GCWCGSAFl
# AwQCAQUABCBwkp1iX+oMbJ57xzk90tLgJDAruy2OtvuxHuFJjS/ZpAIGZmsMWHxY
# GBMyMDI0MDYyMDE1MDAwNC4xMDhaMASAAgH0oIHRpIHOMIHLMQswCQYDVQQGEwJV
# UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
# ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1l
# cmljYSBPcGVyYXRpb25zMScwJQYDVQQLEx5uU2hpZWxkIFRTUyBFU046N0YwMC0w
# NUUwLUQ5NDcxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2Wg
# ghHtMIIHIDCCBQigAwIBAgITMwAAAfAqfB1ZO+YfrQABAAAB8DANBgkqhkiG9w0B
# AQsFADB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
# BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYD
# VQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDAeFw0yMzEyMDYxODQ1
# NTFaFw0yNTAzMDUxODQ1NTFaMIHLMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2Fz
# aGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
# cnBvcmF0aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1lcmljYSBPcGVyYXRpb25z
# MScwJQYDVQQLEx5uU2hpZWxkIFRTUyBFU046N0YwMC0wNUUwLUQ5NDcxJTAjBgNV
# BAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2UwggIiMA0GCSqGSIb3DQEB
# AQUAA4ICDwAwggIKAoICAQC1Hi1Tozh3O0czE8xfRnrymlJNCaGWommPy0eINf+4
# EJr7rf8tSzlgE8Il4Zj48T5fTTOAh6nITRf2lK7+upcnZ/xg0AKoDYpBQOWrL9Ob
# FShylIHfr/DQ4PsRX8GRtInuJsMkwSg63bfB4Q2UikMEP/CtZHi8xW5XtAKp95cs
# 3mvUCMvIAA83Jr/UyADACJXVU4maYisczUz7J111eD1KrG9mQ+ITgnRR/X2xTDMC
# z+io8ZZFHGwEZg+c3vmPp87m4OqOKWyhcqMUupPveO/gQC9Rv4szLNGDaoePeK6I
# U0JqcGjXqxbcEoS/s1hCgPd7Ux6YWeWrUXaxbb+JosgOazUgUGs1aqpnLjz0YKfU
# qn8i5TbmR1dqElR4QA+OZfeVhpTonrM4sE/MlJ1JLpR2FwAIHUeMfotXNQiytYfR
# BUOJHFeJYEflZgVk0Xx/4kZBdzgFQPOWfVd2NozXlC2epGtUjaluA2osOvQHZzGO
# oKTvWUPX99MssGObO0xJHd0DygP/JAVp+bRGJqa2u7AqLm2+tAT26yI5veccDmNZ
# sg3vDh1HcpCJa9QpRW/MD3a+AF2ygV1sRnGVUVG3VODX3BhGT8TMU/GiUy3h7ClX
# OxmZ+weCuIOzCkTDbK5OlAS8qSPpgp+XGlOLEPaM31Mgf6YTppAaeP0ophx345oh
# twIDAQABo4IBSTCCAUUwHQYDVR0OBBYEFNCCsqdXRy/MmjZGVTAvx7YFWpslMB8G
# A1UdIwQYMBaAFJ+nFV0AXmJdg/Tl0mWnG1M1GelyMF8GA1UdHwRYMFYwVKBSoFCG
# Tmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvY3JsL01pY3Jvc29mdCUy
# MFRpbWUtU3RhbXAlMjBQQ0ElMjAyMDEwKDEpLmNybDBsBggrBgEFBQcBAQRgMF4w
# XAYIKwYBBQUHMAKGUGh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvY2Vy
# dHMvTWljcm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIwMTAoMSkuY3J0MAwG
# A1UdEwEB/wQCMAAwFgYDVR0lAQH/BAwwCgYIKwYBBQUHAwgwDgYDVR0PAQH/BAQD
# AgeAMA0GCSqGSIb3DQEBCwUAA4ICAQA4IvSbnr4jEPgo5W4xj3/+0dCGwsz863QG
# Z2mB9Z4SwtGGLMvwfsRUs3NIlPD/LsWAxdVYHklAzwLTwQ5M+PRdy92DGftyEOGM
# Hfut7Gq8L3RUcvrvr0AL/NNtfEpbAEkCFzseextY5s3hzj3rX2wvoBZm2ythwcLe
# ZmMgHQCmjZp/20fHWJgrjPYjse6RDJtUTlvUsjr+878/t+vrQEIqlmebCeEi+VQV
# xc7wF0LuMTw/gCWdcqHoqL52JotxKzY8jZSQ7ccNHhC4eHGFRpaKeiSQ0GXtlbGI
# bP4kW1O3JzlKjfwG62NCSvfmM1iPD90XYiFm7/8mgR16AmqefDsfjBCWwf3qheIM
# fgZzWqeEz8laFmM8DdkXjuOCQE/2L0TxhrjUtdMkATfXdZjYRlscBDyr8zGMlprF
# C7LcxqCXlhxhtd2CM+mpcTc8RB2D3Eor0UdoP36Q9r4XWCVV/2Kn0AXtvWxvIfyO
# Fm5aLl0eEzkhfv/XmUlBeOCElS7jdddWpBlQjJuHHUHjOVGXlrJT7X4hicF1o23x
# 5U+j7qPKBceryP2/1oxfmHc6uBXlXBKukV/QCZBVAiBMYJhnktakWHpo9uIeSnYT
# 6Qx7wf2RauYHIER8SLRmblMzPOs+JHQzrvh7xStx310LOp+0DaOXs8xjZvhpn+Wu
# Zij5RmZijDCCB3EwggVZoAMCAQICEzMAAAAVxedrngKbSZkAAAAAABUwDQYJKoZI
# hvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAw
# DgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
# MjAwBgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0eSAy
# MDEwMB4XDTIxMDkzMDE4MjIyNVoXDTMwMDkzMDE4MzIyNVowfDELMAkGA1UEBhMC
# VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
# BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRp
# bWUtU3RhbXAgUENBIDIwMTAwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoIC
# AQDk4aZM57RyIQt5osvXJHm9DtWC0/3unAcH0qlsTnXIyjVX9gF/bErg4r25Phdg
# M/9cT8dm95VTcVrifkpa/rg2Z4VGIwy1jRPPdzLAEBjoYH1qUoNEt6aORmsHFPPF
# dvWGUNzBRMhxXFExN6AKOG6N7dcP2CZTfDlhAnrEqv1yaa8dq6z2Nr41JmTamDu6
# GnszrYBbfowQHJ1S/rboYiXcag/PXfT+jlPP1uyFVk3v3byNpOORj7I5LFGc6XBp
# Dco2LXCOMcg1KL3jtIckw+DJj361VI/c+gVVmG1oO5pGve2krnopN6zL64NF50Zu
# yjLVwIYwXE8s4mKyzbnijYjklqwBSru+cakXW2dg3viSkR4dPf0gz3N9QZpGdc3E
# XzTdEonW/aUgfX782Z5F37ZyL9t9X4C626p+Nuw2TPYrbqgSUei/BQOj0XOmTTd0
# lBw0gg/wEPK3Rxjtp+iZfD9M269ewvPV2HM9Q07BMzlMjgK8QmguEOqEUUbi0b1q
# GFphAXPKZ6Je1yh2AuIzGHLXpyDwwvoSCtdjbwzJNmSLW6CmgyFdXzB0kZSU2LlQ
# +QuJYfM2BjUYhEfb3BvR/bLUHMVr9lxSUV0S2yW6r1AFemzFER1y7435UsSFF5PA
# PBXbGjfHCBUYP3irRbb1Hode2o+eFnJpxq57t7c+auIurQIDAQABo4IB3TCCAdkw
# EgYJKwYBBAGCNxUBBAUCAwEAATAjBgkrBgEEAYI3FQIEFgQUKqdS/mTEmr6CkTxG
# NSnPEP8vBO4wHQYDVR0OBBYEFJ+nFV0AXmJdg/Tl0mWnG1M1GelyMFwGA1UdIARV
# MFMwUQYMKwYBBAGCN0yDfQEBMEEwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cubWlj
# cm9zb2Z0LmNvbS9wa2lvcHMvRG9jcy9SZXBvc2l0b3J5Lmh0bTATBgNVHSUEDDAK
# BggrBgEFBQcDCDAZBgkrBgEEAYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMC
# AYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBTV9lbLj+iiXGJo0T2UkFvX
# zpoYxDBWBgNVHR8ETzBNMEugSaBHhkVodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20v
# cGtpL2NybC9wcm9kdWN0cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0yMy5jcmwwWgYI
# KwYBBQUHAQEETjBMMEoGCCsGAQUFBzAChj5odHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20vcGtpL2NlcnRzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIzLmNydDANBgkqhkiG
# 9w0BAQsFAAOCAgEAnVV9/Cqt4SwfZwExJFvhnnJL/Klv6lwUtj5OR2R4sQaTlz0x
# M7U518JxNj/aZGx80HU5bbsPMeTCj/ts0aGUGCLu6WZnOlNN3Zi6th542DYunKmC
# VgADsAW+iehp4LoJ7nvfam++Kctu2D9IdQHZGN5tggz1bSNU5HhTdSRXud2f8449
# xvNo32X2pFaq95W2KFUn0CS9QKC/GbYSEhFdPSfgQJY4rPf5KYnDvBewVIVCs/wM
# nosZiefwC2qBwoEZQhlSdYo2wh3DYXMuLGt7bj8sCXgU6ZGyqVvfSaN0DLzskYDS
# PeZKPmY7T7uG+jIa2Zb0j/aRAfbOxnT99kxybxCrdTDFNLB62FD+CljdQDzHVG2d
# Y3RILLFORy3BFARxv2T5JL5zbcqOCb2zAVdJVGTZc9d/HltEAY5aGZFrDZ+kKNxn
# GSgkujhLmm77IVRrakURR6nxt67I6IleT53S0Ex2tVdUCbFpAUR+fKFhbHP+Crvs
# QWY9af3LwUFJfn6Tvsv4O+S3Fb+0zj6lMVGEvL8CwYKiexcdFYmNcP7ntdAoGokL
# jzbaukz5m/8K6TT4JDVnK+ANuOaMmdbhIurwJ0I9JZTmdHRbatGePu1+oDEzfbzL
# 6Xu/OHBE0ZDxyKs6ijoIYn/ZcGNTTY3ugm2lBRDBcQZqELQdVTNYs6FwZvKhggNQ
# MIICOAIBATCB+aGB0aSBzjCByzELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
# bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
# b3JhdGlvbjElMCMGA1UECxMcTWljcm9zb2Z0IEFtZXJpY2EgT3BlcmF0aW9uczEn
# MCUGA1UECxMeblNoaWVsZCBUU1MgRVNOOjdGMDAtMDVFMC1EOTQ3MSUwIwYDVQQD
# ExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNloiMKAQEwBwYFKw4DAhoDFQDC
# KAZKKv5lsdC2yoMGKYiQy79p/6CBgzCBgKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1w
# IFBDQSAyMDEwMA0GCSqGSIb3DQEBCwUAAgUA6h4b+jAiGA8yMDI0MDYyMDAzMDk0
# NloYDzIwMjQwNjIxMDMwOTQ2WjB3MD0GCisGAQQBhFkKBAExLzAtMAoCBQDqHhv6
# AgEAMAoCAQACAgSEAgH/MAcCAQACAhM1MAoCBQDqH216AgEAMDYGCisGAQQBhFkK
# BAIxKDAmMAwGCisGAQQBhFkKAwKgCjAIAgEAAgMHoSChCjAIAgEAAgMBhqAwDQYJ
# KoZIhvcNAQELBQADggEBAELnGa0HR7KbllbMe4P0ZJGV6hxx6xF+GN0EIve5pWW8
# NhF/U4vgSXNzX3et9h4sksGRUABEyaGvpzTEMbhzgV3jfrlFepzNlz/EXhlZs64G
# fNtTS54GhRDE5y/vme+21wk51lxzk7QKOPkYj2qxmbMw7Ue0c/8/jmbZv0wFKIqL
# nyHuib0QtowqTgWoKdcSwfKdBkgWKGaycD3bZf24/nV1rL2tHbXQNCs/KmOR0xuL
# Xk++Hf1BuLFNrCz+GChfsiM0ujayALk2UfqqB48RR38w1CD2meI9NbMEA4b3rTwk
# VmTqkYY+Ekf02mW+E8dxIaCubZnvgQWUP4UY8GiyQhwxggQNMIIECQIBATCBkzB8
# MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
# bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1N
# aWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMAITMwAAAfAqfB1ZO+YfrQABAAAB
# 8DANBglghkgBZQMEAgEFAKCCAUowGgYJKoZIhvcNAQkDMQ0GCyqGSIb3DQEJEAEE
# MC8GCSqGSIb3DQEJBDEiBCCWykQCA3ZIeKZGlvFfwS2cCtorZe4a2lsT/GEaJsG8
# kDCB+gYLKoZIhvcNAQkQAi8xgeowgecwgeQwgb0EIFwBmqOlcv3kU7mAB5sWR74Q
# FAiS6mb+CM6asnFAZUuLMIGYMIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNVBAgT
# Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29m
# dCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENB
# IDIwMTACEzMAAAHwKnwdWTvmH60AAQAAAfAwIgQgaYxIKx9X24hBOUyL6HtAPARU
# i9NjcuTYVFGYdruEk3EwDQYJKoZIhvcNAQELBQAEggIAEpQ4njPOKBjmk7UQFFN2
# mydwZ7fjl162/xjhJGI7ISzaUXOfsJUomKL1F323dZcw8Vy0dWBfAMIQbqEzpvOR
# sl9VyOMjsXrw/IZJot+EoGHINrR8lKKDNcT7ZAbW16PFW/zPSS3i4qGAJpkRzBRR
# 9zeBRqLOl7GnApxPLM4uv9jk0DDBaWDl8oVcs3u5YtUgGK7ORdrcRlUkQEfbBZI7
# sc6MszhWAjR/AMQpjLK9cXi3Nk6bUSqNQGsLKdu+OnHIrLF7A7AKoVrAwTcfGQHJ
# LCxkVoikmrcqJvlzXfoKqqs3qMLlgZXQfOERWIRJlFKwYnaeaxRmaN6viamtoSXW
# G3zxaKAx1nfl0DtbtLD0xfuGTFEsUTAjhRBwpmCWRYPgYs6HS5h/IISIMnPDtDTZ
# WbO/3kQSPCZJ0nsN+JqrNFNY5YFq3h9cl8t4HMDStuoWoevWFAWQlz6itsD8NRuw
# k81NsBYEeAxl3iRk0GyNxTO+zu8x8cEXO3I6AN0VrHQ08RW4VSrTqK6IHYgkIxjP
# VrNzLeIGWg+01iiQvvSiEnkSSHYfQEnyJdUY22DEC84eXUhs35m5h05oaKRU3HxU
# 1XVA42wwkI3qcxQVN4EZDwFvdQFSYTVJX9GZ+nqbPbkXiIl+JEwrSqynkdu7rjVM
# MYvSowosazqAQdwMIIiIZxI=
# SIG # End Windows Authenticode signature block